@@ -9,7 +9,8 @@ class RoundRobin(RAlgorithm):
 
     def execute_r(self, query):
         while self._databases[self._next_db].check_status() == DatabaseStatus.DOWN.value \
-                or not self._databases[self._next_db].queries.empty:
+                or not self._databases[self._next_db].queries.empty\
+                or not self._databases[self._next_db].query_ended.isSet():
             self._next_db += 1
             if self._next_db == len(self._databases): self._next_db = 0
         db_for_read = self._databases[self._next_db]
